(function($) {
  "use strict";

  function generatePieChart(id, data) {
    // Chart properties
    const chartSize = 1024; // Fixed chart size
    const chartCenter = chartSize / 2;
    const chartRadius = chartSize / 2;
  
    // Calculate the total sum of values
    const total = data.reduce((sum, item) => sum + item.value, 0);
  
    // Calculate the angles for each slice
    let startAngle = Math.PI / 2; // Rotate the starting angle by 90 degrees
  
    // Draw the slice
    const canvas = document.getElementById(id);
    const ctx = canvas.getContext("2d");
    ctx.clearRect(0, 0, canvas.width, canvas.height);
  
    data.forEach((item) => {
      const sliceAngle = (item.value / total) * 2 * Math.PI;
  
      // Calculate the position to center the chart
      const chartX = (canvas.width - chartSize) / 2;
      const chartY = (canvas.height - chartSize) / 2;
  
      ctx.beginPath();
      ctx.moveTo(chartX + chartCenter, chartY + chartCenter);
      ctx.arc(
        chartX + chartCenter,
        chartY + chartCenter,
        chartRadius,
        startAngle,
        startAngle + sliceAngle,
        false
      );
      ctx.closePath();
      ctx.fillStyle = item.color;
      ctx.fill();
  
      // Update the start angle for the next slice
      startAngle += sliceAngle;
    });
  }
  
  function generateHorizontalBars(id, data, size, gap) {
    // Chart properties
    const chartWidth = 1024; // Fixed chart width
    const chartHeight = 1024; // Fixed chart height
  
    // Calculate the total sum of values
    const total = data.reduce((sum, item) => sum + item.value, 0);
  
    // Calculate the width of each bar based on the total
    const widthMultiplier = chartWidth / total;
  
    // Draw the bars
    const canvas = document.getElementById(id);
    canvas.classList.add("xel-team--horizontal-bars-canvas");
    const ctx = canvas.getContext("2d");
    ctx.clearRect(0, 0, canvas.width, canvas.height);
  
    let barY = 0;
    const barMultiplier = 100*$(canvas).height()/chartHeight;
  
    const barHeight = size*barMultiplier; // Thickness of the bars
    const barGap = gap*barMultiplier; // Gap between bars
  
    data.forEach((item) => {
      const barWidth = item.value * widthMultiplier;
  
      ctx.fillStyle = item.color;
      ctx.fillRect(0, barY, barWidth, barHeight);
  
      barY += barHeight + barGap;
    });
  }
  
  class XElTeam extends elementorModules.frontend.handlers.Base {
    getDefaultSettings() {
      return {
        selectors: {
          skills: ".xel-team--skills",
          social: ".xel-team--social-networks",
        },
      };
    }

    getDefaultElements() {
      const selectors = this.getSettings("selectors");

      return {
        $skills: this.$element.find(selectors.skills),
        $social: this.$element.find(selectors.social),
      };
    }

    bindEvents() {
      if ( $('#xel-team--noise-filter').length === 0 ) {
        $("body").append('<span class="xel-team--noise-svg"><svg aria-hidden="true"><filter id="xel-team--noise-filter"><feTurbulence type="fractalNoise" baseFrequency="6.29" numOctaves="6" stitchTiles="stitch"></feTurbulence></filter></svg></span>');
      }

      const noiseDetails = this.getElementSettings("xel_team_container_noise");
      
      if ( noiseDetails.size>0 ) {
        this.$element.append('<div class="xel-team--noise-filter" />');
      }

      const id = "xel-team--canvas-" + this.$element[0].dataset.id;
      const dataSocial = $(this.elements.$social[0]).data("social");
      const dataSkill = $(this.elements.$skills[0]).data("skills");
      const chartType = this.getElementSettings("xel_team_skills_type");

      if (this.elements.$social.length > 0) {
        this.elements.$social.find("li").each(function(index, el) {
          $(el)
            .find("a .xel-team--icon")
            .css("color", dataSocial[index].xel_team_social_color);
        });
      }

      if (this.elements.$skills.length > 0) {
        this.elements.$skills.find("li").each(function(index, el) {
          const skillChartLegend = $('<span />').addClass('xel-team--skill-chart-legend').css("background-color", dataSkill[index].xel_team_skill_color);
          $(el).prepend(skillChartLegend);
        });
      }

      if (chartType == "bar") {
        const chartData = [];
        dataSkill.forEach((item, index) => {
          chartData.push({
            value: item.xel_team_skill_value.size,
            color: item.xel_team_skill_color,
          });
        });
        generateHorizontalBars(id, chartData, this.getElementSettings("xel_team_skills_bar_size").size, this.getElementSettings("xel_team_skills_bar_gap").size);
      } else if (chartType == "pie") {
        const chartData = [];
        dataSkill.forEach((item, index) => {
          chartData.push({
            value: item.xel_team_skill_value.size,
            color: item.xel_team_skill_color,
          });
        });
        generatePieChart(id, chartData);
      }
    }
  }

  $(window).on("elementor/frontend/init", () => {
    const addHandler = ($element) => {
      elementorFrontend.elementsHandler.addHandler(XElTeam, {
        $element,
      });
    };

    elementorFrontend.hooks.addAction(
      "frontend/element_ready/xel-team.default",
      addHandler
    );
  });
})(jQuery);
