<?php

class XEl_Common {

	static function get_plugin_prefix() {
		return 'xel_team_';
	}

	public static function get_typography( &$_this, $p, $c ) {
		$_this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			array(
				'name'     => self::get_plugin_prefix() . $p . '_typography',
				'label'    => esc_html__( 'Typography', 'xel-team' ),
				'selector' => '{{WRAPPER}} ' . $c,
			)
		);
	}

	public static function get_color( &$_this, $p, $c ) {
		$_this->add_control(
			self::get_plugin_prefix() . $p . '_color',
			array(
				'label'     => esc_html__( 'Color', 'xel-team' ),
				'type'      => \Elementor\Controls_Manager::COLOR,
				'selectors' => array(
					'{{WRAPPER}} ' . $c => 'color: {{VALUE}};',
				),
			)
		);
	}

	public static function get_padding( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_padding',
			array(
				'label'      => esc_html__( 'Padding', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', 'em', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_margin( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_margin',
			array(
				'label'      => esc_html__( 'Margin', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', 'em', '%' ),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_dimensions( &$_this, $p, $c ) {
		self::get_margin( $_this, $p, $c );
		self::get_padding( $_this, $p, $c );
	}

	public static function get_shadow( &$_this, $p, $c ) {
		$_this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			array(
				'name'     => self::get_plugin_prefix() . $p . '_box_shadow',
				'selector' => '{{WRAPPER}} ' . $c,
			)
		);
	}

	public static function get_background( &$_this, $p, $c ) {
		$_this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			array(
				'name'     => self::get_plugin_prefix() . $p . '_background',
				'label'    => esc_html__( 'Background', 'xel-team' ),
				'types'    => array( 'classic', 'gradient', 'video' ),
				'selector' => '{{WRAPPER}} ' . $c,
			)
		);
	}

	public static function get_border( &$_this, $p, $c ) {
		$_this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			array(
				'name'     => self::get_plugin_prefix() . $p . '_border',
				'label'    => esc_html__( 'Border', 'xel-team' ),
				'selector' => '{{WRAPPER}} ' . $c,
			)
		);

		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_flex_card( &$_this, $p, $c ) {
		self::get_flex_direction( $_this, $p, $c, 'column' );
		self::get_flex_align( $_this, $p, $c );
		self::get_flex_gap( $_this, $p, $c );
	}

	public static function get_flex_list( &$_this, $p, $c ) {
		self::get_flex_direction( $_this, $p, $c, 'row' );
		self::get_flex_list_align( $_this, $p, $c );
		self::get_flex_list_gap( $_this, $p, $c );
	}

	public static function get_flex_direction( &$_this, $p, $c, $d ) {
		$_this->add_control(
			self::get_plugin_prefix() . $p . '_flex_direction',
			array(
				'label'     => esc_html__( 'Direction', 'xel-team' ),
				'type'      => \Elementor\Controls_Manager::SELECT,
				'default'   => in_array( $d, array( 'row', 'column' ), true ) ? $d : 'row',
				'options'   => array(
					'row'    => esc_html__( 'Row', 'xel-team' ),
					'column' => esc_html__( 'Column', 'xel-team' ),
				),
				'selectors' => array(
					'{{WRAPPER}} ' . $c => 'flex-direction: {{VALUE}};',
				),
			)
		);
	}


	public static function get_flex_list_align( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_align_items',
			array(
				'label'       => esc_html__( 'Align', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::CHOOSE,
				'condition'   => array(
					self::get_plugin_prefix() . $p . '_flex_direction' => 'column',
				),
				'options'     => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'xel-team' ),
						'icon'  => 'eicon-align-start-v',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'xel-team' ),
						'icon'  => 'eicon-align-center-v',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'xel-team' ),
						'icon'  => 'eicon-align-end-v',
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} ' . $c => 'align-items: {{VALUE}};',
				),
				'toggle'      => true,
				'label_block' => false,
			)
		);

		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_justify_items',
			array(
				'label'       => esc_html__( 'Justify', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::CHOOSE,
				'condition'   => array(
					self::get_plugin_prefix() . $p . '_flex_direction' => 'row',
				),
				'options'     => array(
					'flex-start'    => array(
						'title' => esc_html__( 'Start', 'xel-team' ),
						'icon'  => 'eicon-align-start-h',
					),
					'center'        => array(
						'title' => esc_html__( 'Center', 'xel-team' ),
						'icon'  => 'eicon-align-center-h',
					),
					'flex-end'      => array(
						'title' => esc_html__( 'End', 'xel-team' ),
						'icon'  => 'eicon-align-end-h',
					),
					'space-between' => array(
						'title' => esc_html__( 'Space between', 'xel-team' ),
						'icon'  => 'eicon-justify-space-between-h',
					),
					'space-evenly'  => array(
						'title' => esc_html__( 'Space evenly', 'xel-team' ),
						'icon'  => 'eicon-justify-space-evenly-h',
					),
					'space-around'  => array(
						'title' => esc_html__( 'Space around', 'xel-team' ),
						'icon'  => 'eicon-justify-space-around-h',
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} ' . $c => 'justify-content: {{VALUE}};',
				),
				'toggle'      => true,
				'label_block' => false,
			)
		);
	}

	public static function get_flex_align( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_align_items',
			array(
				'label'       => esc_html__( 'Align', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::CHOOSE,
				'condition'   => array(
					self::get_plugin_prefix() . $p . '_flex_direction' => 'row',
				),
				'options'     => array(
					'flex-start' => array(
						'title' => esc_html__( 'Start', 'xel-team' ),
						'icon'  => 'eicon-align-start-v',
					),
					'center'     => array(
						'title' => esc_html__( 'Center', 'xel-team' ),
						'icon'  => 'eicon-align-center-v',
					),
					'flex-end'   => array(
						'title' => esc_html__( 'End', 'xel-team' ),
						'icon'  => 'eicon-align-end-v',
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} ' . $c => 'align-items: {{VALUE}};',
				),
				'toggle'      => true,
				'label_block' => false,
			)
		);
	}

	public static function get_flex_gap( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_gap',
			array(
				'label'      => esc_html__( 'Gap', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%', 'em' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 10,
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'gap: {{SIZE}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_flex_list_gap( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_column_gap',
			array(
				'label'      => esc_html__( 'Column gap', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'condition'  => array(
					self::get_plugin_prefix() . $p . '_flex_direction' => 'row',
				),
				'size_units' => array( 'px', '%', 'em' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 10,
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'column-gap: {{SIZE}}{{UNIT}};',
				),
			)
		);

		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_flex_row_gap',
			array(
				'label'      => esc_html__( 'Row gap', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'condition'  => array(
					self::get_plugin_prefix() . $p . '_flex_direction' => 'column',
				),
				'size_units' => array( 'px', '%', 'em' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 10,
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'row-gap: {{SIZE}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_min_height( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_min_height',
			array(
				'label'      => esc_html__( 'Min height', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%', 'em' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 160,
						'step' => 1,
					),
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'em' => array(
						'min'  => 0,
						'max'  => 10,
						'step' => 0.1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 10,
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'min-height: {{SIZE}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_background_blur( &$_this, $p, $c ) {
		$_this->add_control(
			self::get_plugin_prefix() . $p . '_background_blur',
			array(
				'label'      => esc_html__( 'Background blur', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'px' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
				),
				'default'    => array(
					'unit' => 'px',
					'size' => 0,
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'backdrop-filter: blur( {{SIZE}}{{UNIT}} );',
				),
			)
		);
	}

	public static function get_max_width( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_max_width',
			array(
				'label'      => esc_html__( 'Max width', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( 'px', '%', 'em' ),
				'range'      => array(
					'px' => array(
						'min'  => 0,
						'max'  => 1024,
						'step' => 1,
					),
					'%'  => array(
						'min' => 0,
						'max' => 100,
					),
					'em' => array(
						'min'  => 0,
						'max'  => 64,
						'step' => 0.1,
					),
				),
				'selectors'  => array(
					'{{WRAPPER}} ' . $c => 'max-width: {{SIZE}}{{UNIT}};',
				),
			)
		);
	}

	public static function get_text_align( &$_this, $p, $c ) {
		$_this->add_responsive_control(
			self::get_plugin_prefix() . $p . '_align',
			array(
				'label'       => esc_html__( 'Alignment', 'xel-coupon-code' ),
				'type'        => \Elementor\Controls_Manager::CHOOSE,
				'options'     => array(
					'left'   => array(
						'title' => esc_html__( 'Left', 'xel-coupon-code' ),
						'icon'  => 'eicon-text-align-left',
					),
					'center' => array(
						'title' => esc_html__( 'Center', 'xel-coupon-code' ),
						'icon'  => 'eicon-text-align-center',
					),
					'right'  => array(
						'title' => esc_html__( 'Right', 'xel-coupon-code' ),
						'icon'  => 'eicon-text-align-right',
					),
				),
				'selectors'   => array(
					'{{WRAPPER}} ' . $c => 'text-align: {{VALUE}};',
				),
				'toggle'      => true,
				'label_block' => false,
			)
		);
	}

}
