<?php

if ( ! defined( 'ABSPATH' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit;
}

/**
 * XElementor Coupon Code Elementor Widget
 *
 * @since 1.0.0
 */

use Elementor\Controls_Manager;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Widget_Base;
use Elementor\Utils;

class Elementor_XEl_Team extends \Elementor\Widget_Base {


	/**
	 * Load scripts.
	 *
	 * Load script and stylesheet for the plugin.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function __construct( $data = array(), $args = null ) {
		parent::__construct( $data, $args );

		wp_register_script( 'xel-team-script', XElTeam()->plugin_url() . '/assets/js/scripts.js', array( 'elementor-frontend', 'jquery' ), XElTeam()->version(), true );
		wp_register_style( 'xel-team-stylesheet', XElTeam()->plugin_url() . '/assets/css/styles' . ( is_rtl() ? '-rtl' : '' ) . '.css', false, XElTeam()->version() );
	}

	public function get_script_depends() {
		return array( 'xel-team-script' );
	}


	public function get_style_depends() {
		return array( 'xel-team-stylesheet' );
	}


	/**
	 * Get widget name.
	 *
	 * Retrieve this widget name.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'xel-team';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve this widget title.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'XE Team', 'xel-team' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve this widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-button';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories this widget belongs to.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return array( 'general' );
	}

	/**
	 * Register this widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 */
	protected function register_controls() {
		// Content controls
		$this->start_controls_section(
			'section_content',
			array(
				'label' => esc_html__( 'Content', 'xel-team' ),
			)
		);

		$this->add_control(
			'xel_team_image',
			array(
				'label'   => esc_html__( 'Photo', 'xel-team' ),
				'type'    => \Elementor\Controls_Manager::MEDIA,
				'default' => array(
					'url' => \Elementor\Utils::get_placeholder_image_src(),
				),
			)
		);

		$this->add_control(
			'xel_team_name',
			array(
				'label'       => esc_html__( 'Name', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'John Doe', 'xel-team' ),
				'placeholder' => esc_html__( 'Enter the team member name', 'xel-team' ),
			)
		);

		$this->add_control(
			'xel_team_position',
			array(
				'label'       => esc_html__( 'Position', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'Position', 'xel-team' ),
				'placeholder' => esc_html__( 'Enter the team member position', 'xel-team' ),
			)
		);

		$this->add_control(
			'xel_team_description',
			array(
				'label'       => esc_html__( 'Description', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::TEXTAREA,
				'default'     => esc_html__( 'Enter the team member description', 'xel-team' ),
				'placeholder' => esc_html__( 'Enter the team member description', 'xel-team' ),
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_social',
			array(
				'label' => esc_html__( 'Social', 'xel-team' ),
			)
		);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'xel_team_social_network_icon',
			array(
				'label'   => esc_html__( 'Icon', 'xel-team' ),
				'type'    => \Elementor\Controls_Manager::ICONS,
				'default' => array(
					'value'   => 'fab fa-facebook-f',
					'library' => 'fa-solid',
				),
			)
		);

		$repeater->add_control(
			'xel_team_social_network',
			array(
				'label'       => esc_html__( 'Name', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'Facebook', 'xel-team' ),
				'placeholder' => esc_html__( 'Enter the social network name', 'xel-team' ),
			)
		);

		$repeater->add_control(
			'xel_team_social_link',
			array(
				'label'   => esc_html__( 'Link', 'xel-team' ),
				'type'    => \Elementor\Controls_Manager::URL,
				'default' => array(
					'url' => 'https://www.facebook.com/',
				),
			)
		);

		$repeater->add_control(
			'xel_team_social_color',
			array(
				'label'   => esc_html__( 'Color', 'xel-team' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '#ff3300',
			)
		);

		$this->add_control(
			'xel_team_social_networks',
			array(
				'label'       => esc_html__( 'Social Networks', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => array(
					array(
						'xel_team_social_network_icon' => array(
							'value'   => 'fab fa-facebook-f',
							'library' => 'fa-solid',
						),
						'xel_team_social_network'      => esc_html__( 'Facebook', 'xel-team' ),
						'xel_team_social_link'         => array(
							'url' => 'https://www.facebook.com/',
						),
						'xel_team_social_color'        => '#ff3300',
					),
					array(
						'xel_team_social_network_icon' => array(
							'value'   => 'fab fa-twitter',
							'library' => 'fa-solid',
						),
						'xel_team_social_network'      => esc_html__( 'Twitter', 'xel-team' ),
						'xel_team_social_link'         => array(
							'url' => 'https://www.twitter.com/',
						),
						'xel_team_social_color'        => '#0033ff',
					),
				),
				'title_field' => '{{{ xel_team_social_network }}}',
			)
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_skills',
			array(
				'label' => esc_html__( 'Skills', 'xel-team' ),
			)
		);

		$repeater_skills = new \Elementor\Repeater();

		$repeater_skills->add_control(
			'xel_team_skill_name',
			array(
				'label'       => esc_html__( 'Name', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::TEXT,
				'default'     => esc_html__( 'Skill', 'xel-team' ),
				'placeholder' => esc_html__( 'Enter the skill name', 'xel-team' ),
			)
		);

		$repeater_skills->add_control(
			'xel_team_skill_value',
			array(
				'label'      => esc_html__( 'Value', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::SLIDER,
				'size_units' => array( '' ),
				'range'      => array(
					'' => array(
						'min' => 0,
						'max' => 100,
					),
				),
				'default'    => array(
					'size' => 50,
				),
			)
		);

		$repeater_skills->add_control(
			'xel_team_skill_color',
			array(
				'label'   => esc_html__( 'Color', 'xel-team' ),
				'type'    => \Elementor\Controls_Manager::COLOR,
				'default' => '#ff3300',
			)
		);

		$this->add_control(
			'xel_team_skills',
			array(
				'label'       => esc_html__( 'Skills', 'xel-team' ),
				'type'        => \Elementor\Controls_Manager::REPEATER,
				'fields'      => $repeater_skills->get_controls(),
				'default'     => array(
					array(
						'xel_team_skill_name'  => esc_html__( 'Skill', 'xel-team' ),
						'xel_team_skill_value' => array(
							'unit' => '',
							'size' => 50,
						),
						'xel_team_skill_color' => '#ff3300',
					),
					array(
						'xel_team_skill_name'  => esc_html__( 'Skill', 'xel-team' ),
						'xel_team_skill_value' => array(
							'unit' => '',
							'size' => 50,
						),
						'xel_team_skill_color' => '#0033ff',
					),
				),
				'title_field' => '{{{ xel_team_skill_name }}}',
			)
		);

		$this->end_controls_section();

		// Container Style controls
		$this->start_controls_section(
			'xel_team_container_style',
			array(
				'label' => esc_html__( 'Card', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'xel_team_style_container_tabs' );

		$this->start_controls_tab(
			'xel_team_style_container_flex_tab',
			array(
				'label' => esc_html__( 'Layout', 'xel-team' ),
			)
		);

		XEl_Common::get_flex_card( $this, 'container', '.xel-team--team-member' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_style_container_tab',
			array(
				'label' => esc_html__( 'Style', 'xel-team' ),
			)
		);

		XEl_Common::get_dimensions( $this, 'container', '.xel-team--team-member' );

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			array(
				'name'     => 'xel_team_container_border',
				'label'    => esc_html__( 'Border', 'xel-team' ),
				'selector' => '{{WRAPPER}} .xel-team--team-member',
			)
		);

		$this->add_responsive_control(
			'xel_team_container_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} .xel-team--team-member'  => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .xel-team--noise-filter' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		XEl_Common::get_shadow( $this, 'container', '.xel-team--team-member' );
		XEl_Common::get_background( $this, 'container', '.xel-team--team-member' );
		XEl_Common::get_background_blur( $this, 'container', '.xel-team--team-member' );

		$this->add_control(
			'xel_team_container_noise',
			array(
				'label'              => esc_html__( 'Noise', 'xel-team' ),
				'type'               => \Elementor\Controls_Manager::SLIDER,
				'size_units'         => array( '' ),
				'range'              => array(
					'' => array(
						'min'  => 0,
						'max'  => 100,
						'step' => 1,
					),
				),
				'default'            => array(
					'unit' => '',
					'size' => 0,
				),
				'selectors'          => array(
					'{{WRAPPER}} .xel-team--noise-filter' => 'opacity: .{{SIZE}};',
				),
				'frontend_available' => true,
			)
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Image Style controls
		$this->start_controls_section(
			'section_image_style',
			array(
				'label' => esc_html__( 'Image', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'xel_team_style_image_tabs' );

		$this->start_controls_tab(
			'xel_team_style_image_wrapper_tab',
			array(
				'label' => esc_html__( 'Wrapper', 'xel-team' ),
			)
		);

		XEl_Common::get_border( $this, 'image_wrap', '.xel-team--team-member-img-wrap' );
		XEl_Common::get_padding( $this, 'image_wrap', '.xel-team--team-member-img-wrap' );
		XEl_Common::get_shadow( $this, 'image_wrap', '.xel-team--team-member-img-wrap' );
		XEl_Common::get_background( $this, 'image_wrap', '.xel-team--team-member-img-wrap' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_style_image_tab',
			array(
				'label' => esc_html__( 'Img', 'xel-team' ),
			)
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			array(
				'name'     => 'xel_team_image_border',
				'label'    => esc_html__( 'Border', 'xel-team' ),
				'selector' => '{{WRAPPER}} img',
			)
		);

		$this->add_responsive_control(
			'xel_team_image_border_radius',
			array(
				'label'      => esc_html__( 'Border radius', 'xel-team' ),
				'type'       => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => array( 'px', '%', 'em' ),
				'selectors'  => array(
					'{{WRAPPER}} img'               => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					'{{WRAPPER}} .xel-team--canvas' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				),
			)
		);

		XEl_Common::get_dimensions( $this, 'image', 'img' );
		XEl_Common::get_shadow( $this, 'image', 'img' );
		XEl_Common::get_background( $this, 'image', 'img' );
		XEl_Common::get_max_width( $this, 'image', 'img' );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Content Style controls
		$this->start_controls_section(
			'section_content_style',
			array(
				'label' => esc_html__( 'Content', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		XEl_Common::get_dimensions( $this, 'content', '.xel-team--team-member-content' );
		XEl_Common::get_border( $this, 'content', '.xel-team--team-member-content' );
		XEl_Common::get_shadow( $this, 'content', '.xel-team--team-member-content' );
		XEl_Common::get_background( $this, 'content', '.xel-team--team-member-content' );

		$this->end_controls_section();

		// Text Style controls
		$this->start_controls_section(
			'section_text_style',
			array(
				'label' => esc_html__( 'Text', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->start_controls_tabs( 'xel_team_style_text_tabs' );

		$this->start_controls_tab(
			'xel_team_heading_tab',
			array(
				'label' => esc_html__( 'H2', 'xel-team' ),
			)
		);

		XEl_Common::get_typography( $this, 'text', 'h3' );
		XEl_Common::get_text_align( $this, 'text', 'h3' );
		XEl_Common::get_color( $this, 'text', 'h3' );
		XEl_Common::get_dimensions( $this, 'text', 'h3' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_position_tab',
			array(
				'label' => esc_html__( 'Position', 'xel-team' ),
			)
		);

		XEl_Common::get_typography( $this, 'position', '.xel-team--position' );
		XEl_Common::get_text_align( $this, 'position', '.xel-team--position' );
		XEl_Common::get_color( $this, 'position', '.xel-team--position' );
		XEl_Common::get_dimensions( $this, 'position', '.xel-team--position' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_description_tab',
			array(
				'label' => esc_html__( 'Desc', 'xel-team' ),
			)
		);

		XEl_Common::get_typography( $this, 'description', '.xel-team--description' );
		XEl_Common::get_text_align( $this, 'description', '.xel-team--description' );
		XEl_Common::get_color( $this, 'description', '.xel-team--description' );
		XEl_Common::get_dimensions( $this, 'description', '.xel-team--description' );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Social Networks Style controls
		$this->start_controls_section(
			'section_social_style',
			array(
				'label' => esc_html__( 'Social', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'xel_team_social_text',
			array(
				'label'        => esc_html__( 'Show', 'xel-team' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'xel-team' ),
				'label_off'    => esc_html__( 'No', 'xel-team' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);

		$this->add_control(
			'xel_team_social_labels',
			array(
				'label'        => esc_html__( 'Text', 'xel-team' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'xel-team' ),
				'label_off'    => esc_html__( 'No', 'xel-team' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);

		$this->start_controls_tabs( 'xel_team_style_social_tabs' );

		$this->start_controls_tab(
			'xel_team_social_flex_tab',
			array(
				'label' => esc_html__( 'Layout', 'xel-team' ),
			)
		);

		XEl_Common::get_flex_list( $this, 'social', '.xel-team--social-networks' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_social_style_tab',
			array(
				'label' => esc_html__( 'Style', 'xel-team' ),
			)
		);

		XEl_Common::get_color( $this, 'social', '.xel-team--social-networks a' );
		XEl_Common::get_typography( $this, 'social', '.xel-team--social-networks' );
		XEl_Common::get_dimensions( $this, 'social', '.xel-team--social-networks' );
		XEl_Common::get_border( $this, 'social', '.xel-team--social-networks' );
		XEl_Common::get_shadow( $this, 'social', '.xel-team--social-networks' );
		XEl_Common::get_background( $this, 'social', '.xel-team--social-networks' );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

		// Skills Style controls
		$this->start_controls_section(
			'section_skills_style',
			array(
				'label' => esc_html__( 'Skills', 'xel-team' ),
				'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
			)
		);

		$this->add_control(
			'xel_team_skills_text',
			array(
				'label'        => esc_html__( 'Show', 'xel-team' ),
				'type'         => \Elementor\Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'Yes', 'xel-team' ),
				'label_off'    => esc_html__( 'No', 'xel-team' ),
				'return_value' => 'yes',
				'default'      => 'yes',
			)
		);

		$this->add_control(
			'xel_team_skills_type',
			array(
				'label'              => esc_html__( 'Type', 'xel-team' ),
				'type'               => \Elementor\Controls_Manager::SELECT,
				'default'            => 'pie',
				'options'            => array(
					'hide' => esc_html__( 'Hide', 'xel-team' ),
					'bar'  => esc_html__( 'Bars', 'xel-team' ),
					'pie'  => esc_html__( 'Pie', 'xel-team' ),
				),
				'frontend_available' => true,
			)
		);

		$this->add_control(
			'xel_team_skills_bar_size',
			array(
				'label'              => esc_html__( 'Bar size', 'xel-team' ),
				'type'               => \Elementor\Controls_Manager::SLIDER,
				'condition'          => array(
					'xel_team_skills_type' => 'bar',
				),
				'size_units'         => array( '' ),
				'range'              => array(
					'' => array(
						'min'  => 0,
						'max'  => 30,
						'step' => 1,
					),
				),
				'default'            => array(
					'unit' => '',
					'size' => 5,
				),
				'frontend_available' => true,
			)
		);

		$this->add_control(
			'xel_team_skills_bar_gap',
			array(
				'label'              => esc_html__( 'Bar gap', 'xel-team' ),
				'type'               => \Elementor\Controls_Manager::SLIDER,
				'condition'          => array(
					'xel_team_skills_type' => 'bar',
				),
				'size_units'         => array( '' ),
				'range'              => array(
					'' => array(
						'min'  => 0,
						'max'  => 30,
						'step' => 1,
					),
				),
				'default'            => array(
					'unit' => '',
					'size' => 5,
				),
				'frontend_available' => true,
			)
		);

		$this->start_controls_tabs( 'xel_team_style_skills_tabs' );

		$this->start_controls_tab(
			'xel_team_skills_flex_tab',
			array(
				'label' => esc_html__( 'Layout', 'xel-team' ),
			)
		);

		XEl_Common::get_flex_list( $this, 'skills', '.xel-team--skills' );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'xel_team_skills_style_tab',
			array(
				'label' => esc_html__( 'Style', 'xel-team' ),
			)
		);

		XEl_Common::get_color( $this, 'skills', '.xel-team--skills' );
		XEl_Common::get_typography( $this, 'skills', '.xel-team--skills' );
		XEl_Common::get_dimensions( $this, 'skills', '.xel-team--skills' );
		XEl_Common::get_border( $this, 'skills', '.xel-team--skills' );
		XEl_Common::get_shadow( $this, 'skills', '.xel-team--skills' );
		XEl_Common::get_background( $this, 'skills', '.xel-team--skills' );

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();

	}

	/**
	 * Render this widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 */
	protected function render() {
		$id       = $this->get_id();
		$settings = $this->get_settings_for_display();

		// Retrieve settings
		$name            = $settings['xel_team_name'];
		$position        = $settings['xel_team_position'];
		$description     = $settings['xel_team_description'];
		$image_url       = $settings['xel_team_image']['url'];
		$social_networks = $settings['xel_team_social_networks'];
		$social_text     = $settings['xel_team_social_text'];
		$social_labels   = $settings['xel_team_social_labels'];
		$skills          = $settings['xel_team_skills'];
		$skill_text      = $settings['xel_team_skills_text'];

		// Output HTML
		?>
		<div id="xel-team-<?php echo esc_attr( $id ); ?>" class="xel-team--team-member">
			<div class="xel-team--team-member-img-wrap">
				<canvas id="xel-team--canvas-<?php echo esc_attr( $id ); ?>" class="xel-team--canvas" width="1024" height="1024"></canvas>
				<div class="xel-team--team-member-img">
					<img src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( $name ); ?>">
				</div>
			</div>
			<div class="xel-team--team-member-content">
				<h3><?php echo esc_html( $name ); ?></h3>
				<p class="xel-team--position"><?php echo esc_html( $position ); ?></p>
				<p class="xel-team--description"><?php echo esc_html( $description ); ?></p>

				<?php if ( 'yes' === $social_text && ! empty( $social_networks ) ) : ?>
					<ul class="xel-team--social-networks" data-social="<?php echo htmlspecialchars( json_encode( $social_networks ) ); ?>">
						<?php foreach ( $social_networks as $network ) : ?>
							<?php $network_icon = $network['xel_team_social_network_icon']; ?>
							<?php $network_name = $network['xel_team_social_network']; ?>
							<?php $network_link = $network['xel_team_social_link']['url']; ?>

							<li><a href="<?php echo esc_url( $network_link ); ?>"><span class="xel-team--icon"><?php \Elementor\Icons_Manager::render_icon( $network_icon, array( 'aria-hidden' => 'true' ) ); ?></span> 
													<?php
													if ( 'yes' === $social_labels ) {
														echo esc_html( $network_name ); }
													?>
							</a></li>
						<?php endforeach; ?>
					</ul>
				<?php endif; ?>

				<?php if ( ! empty( $skills ) ) : ?>
					<ul class="xel-team--skills" data-skills="<?php echo htmlspecialchars( json_encode( $skills ) ); ?>">
						<?php if ( 'yes' === $skill_text ) : ?>
							<?php foreach ( $skills as $skill ) : ?>
								<?php $skill_name = $skill['xel_team_skill_name']; ?>
								<?php $skill_value = $skill['xel_team_skill_value']['size']; ?>

								<li>
									<span class="xel-team--skill-name"><?php echo esc_html( $skill_name ); ?></span>
									<span class="xel-team--skill-value"><?php echo esc_html( $skill_value ); ?>%</span>
								</li>
							<?php endforeach; ?>
						<?php endif; ?>
					</ul>
				<?php endif; ?>
			</div>
		</div>
		<?php
	}

}
